@@ -85,9 +85,21 @@ STRUCTURE = Nav(
 					lazy_gettext("Mécaniques de la colorpie"),
 					index=False,
 					children=[
+						Nav(lazy_gettext("La Destruction de permanents")),
+						Nav(lazy_gettext("Les Cartes de taxe")),
+						Nav(lazy_gettext("La Protection")),
 						Nav(lazy_gettext("Les Contresorts")),
+						Nav(lazy_gettext("Le Bounce de permanents")),
+						Nav(lazy_gettext("Les Cantrips")),
 						Nav(lazy_gettext("La Défausse")),
+						Nav(lazy_gettext("La Gestion de créatures")),
+						Nav(lazy_gettext("La Réanimation de créatures")),
 						Nav(lazy_gettext("Les Dégâts directs")),
+						Nav(lazy_gettext("Les Créatures agressives")),
+						Nav(lazy_gettext("Le Remplacement de cartes")),
+						Nav(lazy_gettext("Le Ramp")),
+						Nav(lazy_gettext("Les Grosses créatures")),
+						Nav(lazy_gettext("La Recherche de créatures")),
 					],
 				),
 				Nav(
